@@ -71,7 +71,7 @@ impl Permissions {
         let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/files/{}/permissions?{}",
-            crate::progenitor_support::encode_path(&file_id.to_string()),
+            crate::progenitor_support::encode_path(file_id),
             query_
         );
 
@@ -124,7 +124,7 @@ impl Permissions {
         let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/files/{}/permissions?{}",
-            crate::progenitor_support::encode_path(&file_id.to_string()),
+            crate::progenitor_support::encode_path(file_id),
             query_
         );
 
@@ -230,7 +230,7 @@ impl Permissions {
         let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/files/{}/permissions?{}",
-            crate::progenitor_support::encode_path(&file_id.to_string()),
+            crate::progenitor_support::encode_path(file_id),
             query_
         );
 
@@ -282,8 +282,8 @@ impl Permissions {
         let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/files/{}/permissions/{}?{}",
-            crate::progenitor_support::encode_path(&file_id.to_string()),
-            crate::progenitor_support::encode_path(&permission_id.to_string()),
+            crate::progenitor_support::encode_path(file_id),
+            crate::progenitor_support::encode_path(permission_id),
             query_
         );
 
@@ -333,8 +333,8 @@ impl Permissions {
         let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/files/{}/permissions/{}?{}",
-            crate::progenitor_support::encode_path(&file_id.to_string()),
-            crate::progenitor_support::encode_path(&permission_id.to_string()),
+            crate::progenitor_support::encode_path(file_id),
+            crate::progenitor_support::encode_path(permission_id),
             query_
         );
 
@@ -401,8 +401,8 @@ impl Permissions {
         let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/files/{}/permissions/{}?{}",
-            crate::progenitor_support::encode_path(&file_id.to_string()),
-            crate::progenitor_support::encode_path(&permission_id.to_string()),
+            crate::progenitor_support::encode_path(file_id),
+            crate::progenitor_support::encode_path(permission_id),
             query_
         );
 
